<?php

namespace Drupal\access_policy\Plugin\access_policy\AccessPolicyType;

use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\user\EntityOwnerInterface;

/**
 * Private access policy type.
 *
 * @AccessPolicyType(
 *   id = "private",
 *   label = @Translation("Private"),
 *   description = @Translation("Restrict view, edit and delete access to the original author."),
 *   weight = -1,
 *   operations = {
 *     "view" = {
 *       "rules" = true,
 *     },
 *     "view all revisions" = {
 *       "rules" = true,
 *     },
 *     "update" = {
 *       "rules" = true,
 *      },
 *     "delete" = {
 *       "rules" = true,
 *      },
 *     "view unpublished" = {
 *       "rules" = true,
 *      },
 *     "manage access" = { },
 *   },
 *   access_rules = {
 *     "is_own" = {
 *       "id" = "is_own",
 *       "plugin_id" = "is_own",
 *       "field" = "uid",
 *       "required" = true,
 *     },
 *   },
 *   selection_rules = {
 *     "is_own" = {
 *       "id" = "is_own",
 *       "plugin_id" = "is_own",
 *       "field" = "uid",
 *       "required" = true,
 *     },
 *   },
 * )
 *
 * @deprecated in access_policy:1.0.0-beta7 and is removed from access_policy:1.0.0-beta8. There is no
 *   replacement.
 *
 * @see https://www.drupal.org/project/access_policy/issues/3419014
 */
class PrivateAccess extends AccessPolicyTypeBase {

  /**
   * {@inheritdoc}
   */
  public static function isApplicable(EntityTypeInterface $entity_type) {
    return $entity_type->entityClassImplements(EntityOwnerInterface::class);
  }

}
